@@ -618,9 +618,13 @@ CameraDelegateMethodNames = Literal["reboot", "snapshot"]
 class CameraPrebufferDelegate(metaclass=ABCMeta):
     @abstractmethod
     async def getStreamInfo(self, source_name: str) -> Optional[StreamInfo]: ...
+    @abstractmethod
+    async def getPrebufferingState(
+        self, source_name: str, container: Container
+    ) -> Optional[PrebufferState]: ...
 
 
-CameraPrebufferDelegateMethodNames = Literal["getStreamInfo"]
+CameraPrebufferDelegateMethodNames = Literal["getStreamInfo", "getPrebufferingState"]
 
 
 class CameraPTZDelegate(metaclass=ABCMeta):
